pub struct FixThinPackBuild {
pub pack: Vec<u8>,
pub index: PackIndexBuild,
pub appended_bases: Vec<ObjectId>,
}Expand description
A self-contained pack and the v2 index built for its final bytes.
Fields
pack: Vec<u8>The completed pack. This is byte-for-byte identical to the input when the input was already self-contained.
index: PackIndexBuildThe v2 index build corresponding to pack.
appended_bases: Vec<ObjectId>External base object ids appended to the pack, in append order.