pub struct PackIndexViewData {
pub version: u32,
pub count: usize,
pub fanout: [u32; 256],
pub pack_checksum: ObjectId,
pub index_checksum: ObjectId,
/* private fields */
}Fields
version: u32count: usizefanout: [u32; 256]pack_checksum: ObjectIdindex_checksum: ObjectIdImplementations
Sourceimpl PackIndexViewData
impl PackIndexViewData
pub fn parse(bytes: Arc<[u8]>, format: ObjectFormat) -> Result<Self>
Sourcepub fn parse_without_checksum(
bytes: Arc<[u8]>,
format: ObjectFormat,
) -> Result<Self>
pub fn parse_without_checksum( bytes: Arc<[u8]>, format: ObjectFormat, ) -> Result<Self>
Parse and validate an owned index view without recomputing the trailing
index checksum. The stored checksum is still exposed via
PackIndexViewData::index_checksum.
Sourcepub fn parse_trusted_without_checksum(
bytes: Arc<[u8]>,
format: ObjectFormat,
) -> Result<Self>
pub fn parse_trusted_without_checksum( bytes: Arc<[u8]>, format: ObjectFormat, ) -> Result<Self>
Parse a local/trusted owned index view without the checksum or full-entry validation passes.
pub fn parse_source( bytes: Arc<dyn PackIndexByteSource>, format: ObjectFormat, ) -> Result<Self>
pub fn parse_source_without_checksum( bytes: Arc<dyn PackIndexByteSource>, format: ObjectFormat, ) -> Result<Self>
pub fn parse_trusted_source_without_checksum( bytes: Arc<dyn PackIndexByteSource>, format: ObjectFormat, ) -> Result<Self>
pub fn count(&self) -> usize
pub fn fanout(&self) -> &[u32; 256]
pub fn find(&self, oid: &ObjectId) -> Option<PackIndexLookup>
pub fn as_view(&self) -> PackIndexView<'_>