PackWriteSummary

Struct PackWriteSummary 

pub struct PackWriteSummary {
    pub index: Vec<u8>,
    pub checksum: ObjectId,
    pub entries: Vec<PackIndexEntry>,
    pub delta_count: u32,
    pub pack_size: u64,
    pub peak_working_set_bytes: u64,
}

Fields

index: Vec<u8>checksum: ObjectIdentries: Vec<PackIndexEntry>delta_count: u32pack_size: u64peak_working_set_bytes: u64

High-water mark of decoded window bodies plus retained delta bases, as charged by PackWriteLimits. Does not include zlib output buffers or allocator slack.