pub trait PackReadSource {
// Required methods
fn len(&self) -> Result<u64>;
fn read_at(&self, offset: u64, buf: &mut [u8]) -> Result<usize>;
// Provided method
fn is_empty(&self) -> Result<bool> { ... }
}Expand description
A source that can read pack bytes positionally without changing shared cursor state or requiring the complete pack to be resident in memory.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl PackReadSource for File
Available on Unix only.
impl PackReadSource for File
Available on Unix only.